.. _spkg_sphinx_basic_ng:

sphinx_basic_ng: Modern skeleton for Sphinx themes
==================================================

Description
-----------

Modern skeleton for Sphinx themes

License
-------

Upstream Contact
----------------

https://pypi.org/project/sphinx-basic-ng/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_pip`
- :ref:`spkg_sphinx`

Version Information
-------------------

package-version.txt::

    1.0.0b2

version_requirements.txt::

    sphinx-basic-ng

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install sphinx-basic-ng

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i sphinx_basic_ng

.. tab:: Arch Linux:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S python-sphinx-basic-ng

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install sphinx-basic-ng

.. tab:: Debian/Ubuntu:

   .. CODE-BLOCK:: bash

       $ sudo apt-get install sphinx-basic-ng

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install python3-sphinx-basic-ng

.. tab:: FreeBSD:

   .. CODE-BLOCK:: bash

       $ sudo pkg install textproc/py-sphinx-basic-ng

.. tab:: Gentoo Linux:

   .. CODE-BLOCK:: bash

       $ sudo emerge dev-python/sphinx-basic-ng


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
